// Author 		: F. de la Parra
// Date			: January, 2019
// Description 	: This program implements a menu whose choices
//				  call methods that exercise some java features: 
//				  if-else, while loops, arrays, object creation,
//				  method invocation and console input/output.
// Version		: 1.0

import java.util.Scanner;
import java.util.Random;

public class WhileDemo {
	
	
	// Method "main" drives topic selection iteratively (i.e.,
	// display menu -> select option -> execute it -> go back
	// to display menu, and start the cycle again)through using
	// a while loop.
	
	public static void main(String[] args) {
		
		// Create object "demoObject" to call instance methods
		// in class "WhileDemo".
		WhileDemo demoObject = new WhileDemo();
		

		// Create a "menuSelect" object to read input from the
		// keyboard (a menu selection integer).
		Scanner menuSelect = new Scanner(System.in);
		
		// "menuItem" will keep track of the menu selection
		// entered from the keyboard. Initialize to 0 (no option
		// selected yet).
		int menuItem = 0;
				
		// Display menu and wait for a menu item selection. When
		// an option is entered, run the associated method that
		// performs the processing offered for that option.
		
		while (menuItem != 9) {
			// Display menu
			System.out.println("\n***JavaDemo Menu ***");
			System.out.println("1 - Console input, while loop, if - else");
			System.out.println("2 - Arrays, for loop");
			System.out.println("3 - Random numbers in range");
			System.out.println("4 - 'Press Enter to continue'");
			System.out.println("9 - Exit");
			System.out.println();
			System.out.println("Enter demo number:");
			
			// Read the menu selection from the keyboard.
			menuItem = menuSelect.nextInt();
			
			// Run demo corresponding to selected menu item.
			if (menuItem == 1) {
				System.out.println("\n*** Running console input demo ***\n");
				
				// Execute console input demo.
				demoObject.consoleIn();
			}
			else if (menuItem == 2) {
				System.out.println("\n*** Running array demo ***\n");
				
				// Execute array demo.
				demoObject.arrayDemo();
			}
			else if (menuItem == 3) {
				System.out.println("\n*** Running random numbers in range demo ***\n");
				
				// Execute random numbers in range demo.
				demoObject.randomNumbersDemo();
			}
			else if (menuItem == 4) {
				System.out.println("\n*** Running 'Press Enter to continue' demo ***\n");
				
				// Execute 'Press Enter to continue' demo.
				demoObject.pressEnterDemo();
			}
			// else if (menuItem == n)     More upcoming demos ...
		}
	}
	
	// Method consoleIn exercises console I/O, loops, conditionals and
	// use of boolean expressions.
	
	public void consoleIn() {
		Scanner keyboard = new Scanner(System.in);
		
		System.out.println("Enter room number (nnn): ");
		int numberOfBooks = keyboard.nextInt();
		System.out.println("Room number is " + numberOfBooks);
		
		System.out.println("\nEnter room type: ");
		String firstName = keyboard.next();
		System.out.println("Room type is " + firstName);
		
		String referenceCode = "A1";
		String searchCode;
		boolean invalidCode = true;
		
		// Simulate doing something if an entered code is "A1".
		while (invalidCode) {
			System.out.println("\nEnter search code (A1 is correct)");
			searchCode = keyboard.next();
			if (searchCode.equals(referenceCode)) {
				System.out.println("Search code " + searchCode + " is right");
				invalidCode = false;
			}
			else
				System.out.println("Search code " + searchCode + " is wrong");
		}
	}
	
	// Method arrayDemo shows initialization and use of arrays of
	// primitive and class-like base types.

	public void arrayDemo() {
		Scanner keyboard = new Scanner(System.in);
		
		// Initialize data for 3 students using multiple arrays of primitive types.
		int[] startYear = {2015,2016,2017};
		boolean[] doubleMajor = {true, false, false};
		double[] gpa = {3.8, 3.6, 3.3};
		
		String[] firstName = {"John", "Mary", "Sarah"};
		String[] lastName = {"Smith", "Lynn", "Boles"};
		
		// Display data for 3 students using a for loop on multiple
		// arrays of primitive types.
		
		System.out.println("*** Display student data from multiple arrays of primitive types ***\n");
		
		for (int i = 0; i < 3; i++) {
			System.out.println("Name: " + firstName[i] + " " + lastName[i]);
			System.out.println("Start year: " + startYear[i]);
			System.out.println("Double major: " + doubleMajor[i]);
			System.out.println("Gpa: " + gpa[i]);
			System.out.println();
		}
		
		// Ask whether to continue or not with the second part of this demo.
		System.out.println("Continue (y/n)?: ");
		String answer = keyboard.next();
		
		
		if (answer.equals("y")) {
			System.out.println("Nothing more to do!");
		}
	}
	
	// Method randomNumbersDemo generates random integers in a range
	// delimited by a specified lower bound.
	
	public void randomNumbersDemo() {
		Scanner selection = new Scanner(System.in);
		
		// Initialize a random number 'generator' object with a seed
		// (i.e., an integer) obtained from the System's time. 
		Random generator = new Random(System.currentTimeMillis());
		
		int nextRandomNumber;		// Stores next random integer
		int lowerBound = 0;			// Minimum random integer
		int range = 0;				// Range of random integers
		int maxCount = 10;			// Maximum number of random integers
		String countMessage = "";	// Stores random number type message;
		
		System.out.println("Generate student numbers or other (s/o)? :");
		String answer = selection.next();
		
		// Set lower bound and range for 8-digit student numbers.
		if (answer.equals("s")) {
			lowerBound = 10000000;
			range = 89999999;
			countMessage = "\n*** Generate " + maxCount + " random student numbers ***\n";
		}
		// Obtain lower bound and range from the user. Defaults are 0 and 100.
		else if (answer.equals("o")) {
			lowerBound = 0;
			range = 100;
			countMessage = "\n*** Generate " + maxCount + " random numbers ***\n";
			
			System.out.println("Enter smallest random integer (0): ");
			lowerBound = selection.nextInt();
			System.out.println("Enter range of random integers (100) : ");
			range = selection.nextInt();
		}
			
		// Generate and display random integers in specified range.
		
		System.out.println(countMessage);
		
		for(int i=0; i < maxCount; i++) {
			nextRandomNumber = lowerBound + generator.nextInt(range);
			System.out.println("Next random integer is : " + nextRandomNumber);
		}
	}
	
	// Method pressEnterDemo waits for the user to press the 'Enter key
	// to continue with the processing.
	
	public void pressEnterDemo() {
		
		// Assume that some processing step has been completed
		System.out.println("<<< Some processing step has been completed >>>");
		System.out.println();
		
		// Inform the user that processing will continue after pressing 'Enter'.
		System.out.println("Press Enter to continue: ");
		
		// Wait for the user to press the 'Enter' key.
		try {
            System.in.read();
        }  
        catch(Exception e){
		} 

		// Resume with following processing step.
		System.out.println();
		System.out.println("<<< Continue with the following processing step >>>");
	}
}